@@ -292,6 +292,11 @@ void ConnectionEditor::addConnection(QAction* action)
         }
     }
 
+    // In case that mobile broadband wizard has not been finished
+    if (!connectionSettings) {
+        return;
+    }
+
     // Generate new UUID
     connectionSettings->setUuid(NetworkManager::ConnectionSettings::createNewUuid());
 
@@ -517,17 +522,6 @@ void ConnectionEditor::storeSecrets(const QMap< QString, QMap< QString, QString
                 }
             }
         }
-    } else {
-        KConfig config("plasma-networkmanagement");
-        foreach (const QString & groupName, map.keys()) {
-            KConfigGroup secretsGroup = config.group(groupName);
-            NMStringMap secretsMap = map.value(groupName);
-            NMStringMap::ConstIterator i = secretsMap.constBegin();
-            while (i != secretsMap.constEnd()) {
-                secretsGroup.writeEntry(i.key(), i.value());
-                ++i;
-            }
-        }
     }
 }
 
