@@ -37,8 +37,9 @@
 
 #include <KPluginFactory>
 #include <KWindowSystem>
+#include <KConfig>
+#include <KConfigGroup>
 #include <KWallet/Wallet>
-
 #include <QDebug>
 
 SecretAgent::SecretAgent(QObject* parent):
@@ -47,6 +48,9 @@ SecretAgent::SecretAgent(QObject* parent):
     m_dialog(0)
 {
     connect(NetworkManager::notifier(), &NetworkManager::Notifier::serviceDisappeared, this, &SecretAgent::killDialogs);
+
+    // We have to import secrets previously stored in plaintext files
+    importSecretsFromPlainTextFiles();
 }
 
 SecretAgent::~SecretAgent()
@@ -486,3 +490,72 @@ void SecretAgent::sendSecrets(const NMVariantMapMap &secrets, const QDBusMessage
         qWarning() << "Failed put the secret into the queue";
     }
 }
+
+void SecretAgent::importSecretsFromPlainTextFiles()
+{
+    KConfig config(QLatin1String("plasma-networkmanagement"), KConfig::SimpleConfig);
+
+    // No action is required when the list of secrets is empty
+    if (!config.groupList().isEmpty()) {
+        foreach (const QString &groupName, config.groupList()) {
+            QString loadedUuid = groupName.split(';').first().remove('{').remove('}');
+            QString loadedSettingType = groupName.split(';').last();
+            NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(loadedUuid);
+            if (connection) {
+                NetworkManager::Setting::SecretFlags secretFlags = KWallet::Wallet::isEnabled() ? NetworkManager::Setting::AgentOwned : NetworkManager::Setting::None;
+                QMap<QString, QString> secrets = config.entryMap(groupName);
+                NMVariantMapMap settings = connection->settings()->toMap();
+
+                foreach (const QString &setting, settings.keys()) {
+                    if (setting == QLatin1String("vpn")) {
+                        NetworkManager::VpnSetting::Ptr vpnSetting = connection->settings()->setting(NetworkManager::Setting::Vpn).staticCast<NetworkManager::VpnSetting>();
+                        if (vpnSetting) {
+                            // Add loaded secrets from the config file
+                            vpnSetting->secretsFromStringMap(secrets);
+
+                            NMStringMap vpnData = vpnSetting->data();
+                            // Reset flags, we can't save secrets to our secret agent when KWallet is not enabled, because
+                            // we dropped support for plaintext files, therefore they need to be stored to NetworkManager
+                            foreach (const QString &key, vpnData.keys()) {
+                                if (key.endsWith(QLatin1String("-flags"))) {
+                                    vpnData.insert(key, QString::number((int)secretFlags));
+                                }
+                            }
+
+                            vpnSetting->setData(vpnData);
+                            settings.insert(setting, vpnSetting->toMap());
+                            connection->update(settings);
+                        }
+                    } else {
+                        if (setting == loadedSettingType) {
+                            QVariantMap tmpSetting = settings.value(setting);
+                            // Reset flags, we can't save secrets to our secret agent when KWallet is not enabled, because
+                            // we dropped support for plaintext files, therefore they need to be stored to NetworkManager
+                            foreach (const QString &key, tmpSetting.keys()) {
+                                if (key.endsWith(QLatin1String("-flags"))) {
+                                    tmpSetting.insert(key, (int)secretFlags);
+                                }
+                            }
+
+                            // Add loaded secrets from the config file
+                            QMap<QString, QString>::const_iterator it = secrets.constBegin();
+                            QMap<QString, QString>::const_iterator end = secrets.constEnd();
+                            for (; it != end; ++it) {
+                                tmpSetting.insert(it.key(), it.value());
+                            }
+
+                            // Replace the old setting with the new one
+                            settings.insert(setting, tmpSetting);
+                            // Update the connection which re-saves secrets
+                            connection->update(settings);
+                        }
+                    }
+                }
+            }
+
+            // Remove the group
+            KConfigGroup group(&config, groupName);
+            group.deleteGroup();
+        }
+    }
+}
