@@ -134,21 +134,36 @@ void NetworkStatus::changeActiveConnections()
                 QString devName;
                 QString conType;
                 QString status;
+                NetworkManager::VpnConnection::Ptr vpnConnection;
+
                 if (device->ipInterfaceName().isEmpty()) {
                     devName = device->interfaceName();
                 } else {
                     devName = device->ipInterfaceName();
                 }
+
                 if (active->vpn()) {
-                    conType = i18n("VPN Connection");
+                    conType = i18n("VPN");
+                    vpnConnection = active.objectCast<NetworkManager::VpnConnection>();
                 } else {
                     conType = UiUtils::interfaceTypeLabel(device->type(), device);
                 }
-                if (active->state() == NetworkManager::ActiveConnection::Activated) {
-                    status = i18n("Connected to %1", active->connection()->name());
-                } else if (active->state() == NetworkManager::ActiveConnection::Activating) {
-                    status = i18n("Connecting to %1", active->connection()->name());
+
+                if (vpnConnection && active->vpn()) {
+                    if (vpnConnection->state() >= NetworkManager::VpnConnection::Prepare &&
+                        vpnConnection->state() <= NetworkManager::VpnConnection::GettingIpConfig) {
+                        status = i18n("Connecting to %1", active->connection()->name());
+                    } else if (vpnConnection->state() == NetworkManager::VpnConnection::Activated) {
+                        status = i18n("Connected to %1", active->connection()->name());
+                    }
+                } else {
+                    if (active->state() == NetworkManager::ActiveConnection::Activated) {
+                        status = i18n("Connected to %1", active->connection()->name());
+                    } else if (active->state() == NetworkManager::ActiveConnection::Activating) {
+                        status = i18n("Connecting to %1", active->connection()->name());
+                    }
                 }
+
                 if (active->default4() || active->default6()) {
                     activeConnections += formatDefault.arg(devName, conType, status);
                 } else {
