@@ -46,6 +46,7 @@
 #include <KService>
 #include <KServiceTypeTrader>
 #include <KWindowSystem>
+#include <KWallet/Wallet>
 
 Handler::Handler(QObject* parent)
     : QObject(parent)
@@ -53,7 +54,12 @@ Handler::Handler(QObject* parent)
     , m_tmpWimaxEnabled(NetworkManager::isWimaxEnabled())
     , m_tmpWirelessEnabled(NetworkManager::isWirelessEnabled())
     , m_tmpWwanEnabled(NetworkManager::isWwanEnabled())
+    , m_agentIface(QStringLiteral("org.kde.kded5"), QStringLiteral("/modules/networkmanagement"),
+                   QStringLiteral("org.kde.plasmanetworkmanagement"))
 {
+    initKdedModule();
+    QDBusConnection::sessionBus().connect(m_agentIface.service(), m_agentIface.path(), m_agentIface.interface(), QStringLiteral("registered"),
+                                          this, SLOT(initKdedModule()));
 }
 
 Handler::~Handler()
@@ -168,7 +174,9 @@ void Handler::addAndActivateConnection(const QString& device, const QString& spe
         if (securityType == NetworkManager::Utils::StaticWep) {
             wifiSecurity->setKeyMgmt(NetworkManager::WirelessSecuritySetting::Wep);
             wifiSecurity->setWepKey0(password);
-            wifiSecurity->setWepKeyFlags(NetworkManager::Setting::AgentOwned);
+            if (KWallet::Wallet::isEnabled()) {
+                wifiSecurity->setWepKeyFlags(NetworkManager::Setting::AgentOwned);
+            }
         } else {
             if (ap->mode() == NetworkManager::AccessPoint::Adhoc) {
                 wifiSecurity->setKeyMgmt(NetworkManager::WirelessSecuritySetting::WpaNone);
@@ -176,7 +184,9 @@ void Handler::addAndActivateConnection(const QString& device, const QString& spe
                 wifiSecurity->setKeyMgmt(NetworkManager::WirelessSecuritySetting::WpaPsk);
             }
             wifiSecurity->setPsk(password);
-            wifiSecurity->setPskFlags(NetworkManager::Setting::AgentOwned);
+            if (KWallet::Wallet::isEnabled()) {
+                wifiSecurity->setPskFlags(NetworkManager::Setting::AgentOwned);
+            }
         }
         QDBusPendingReply<QDBusObjectPath> reply = NetworkManager::addAndActivateConnection(settings->toMap(), device, specificObject);
         QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
@@ -390,6 +400,11 @@ void Handler::requestScan()
     }
 }
 
+void Handler::initKdedModule()
+{
+    m_agentIface.call(QStringLiteral("init"));
+}
+
 void Handler::replyFinished(QDBusPendingCallWatcher * watcher)
 {
     QDBusPendingReply<> reply = *watcher;
