@@ -21,6 +21,8 @@
 #ifndef PLASMA_NM_HANDLER_H
 #define PLASMA_NM_HANDLER_H
 
+#include <QDBusInterface>
+
 #include <NetworkManagerQt/Connection>
 
 #include "plasmanm_export.h"
@@ -106,6 +108,7 @@ public Q_SLOTS:
     void requestScan();
 
 private Q_SLOTS:
+    void initKdedModule();
     void replyFinished(QDBusPendingCallWatcher * watcher);
 
 private:
@@ -118,6 +121,7 @@ private:
     QString m_tmpSpecificPath;
 
     bool isBtEnabled();
+    QDBusInterface m_agentIface;
 };
 
 #endif // PLASMA_NM_HANDLER_H
