@@ -49,9 +49,9 @@ public:
         ConnectionIconRole,
         ConnectionPathRole,
         ConnectionStateRole,
-        DeviceNameRole,
         DevicePathRole,
         DeviceStateRole,
+        DownloadRole,
         DuplicateRole,
         ItemUniqueNameRole,
         ItemTypeRole,
@@ -70,11 +70,13 @@ public:
         TypeRole,
         UniRole,
         UuidRole,
+        UploadRole,
         VpnState,
     };
 
     int rowCount(const QModelIndex& parent) const;
     QVariant data(const QModelIndex& index, int role) const;
+    virtual QHash< int, QByteArray > roleNames() const;
 
 public Q_SLOTS:
     void onItemUpdated();
@@ -100,7 +102,6 @@ private Q_SLOTS:
     void gsmNetworkSignalQualityChanged(uint signal);
 #endif
     void ipConfigChanged();
-    void ipInterfaceChanged();
     void statusChanged(NetworkManager::Status status);
     void wimaxNspAppeared(const QString& nsp);
     void wimaxNspDisappeared(const QString& nsp);
@@ -111,7 +112,6 @@ private Q_SLOTS:
     void wirelessNetworkReferenceApChanged(const QString& accessPoint);
 
     void initialize();
-
 private:
     NetworkItemsList m_list;
 
