@@ -239,19 +239,19 @@ QString NetworkModelItem::icon() const
         case NetworkManager::ConnectionSettings::Wireless:
             if (m_signal == 0 ) {
                 if (m_mode == NetworkManager::WirelessSetting::Adhoc || m_mode == NetworkManager::WirelessSetting::Ap) {
-                    return (m_securityType == NetworkManager::Utils::None) ? "network-wireless-100" : "network-wireless-100-locked";
+                    return (m_securityType <= NetworkManager::Utils::None) ? "network-wireless-100" : "network-wireless-100-locked";
                 }
-                return (m_securityType == NetworkManager::Utils::None) ? "network-wireless-0" : "network-wireless-0-locked";
+                return (m_securityType <= NetworkManager::Utils::None) ? "network-wireless-0" : "network-wireless-0-locked";
             } else if (m_signal < 20) {
-                return (m_securityType == NetworkManager::Utils::None) ? "network-wireless-20" : "network-wireless-20-locked";
+                return (m_securityType <= NetworkManager::Utils::None) ? "network-wireless-20" : "network-wireless-20-locked";
             } else if (m_signal < 40) {
-                return (m_securityType == NetworkManager::Utils::None) ? "network-wireless-40" : "network-wireless-40-locked";
+                return (m_securityType <= NetworkManager::Utils::None) ? "network-wireless-40" : "network-wireless-40-locked";
             } else if (m_signal < 60) {
-                return (m_securityType == NetworkManager::Utils::None) ? "network-wireless-60" : "network-wireless-60-locked";
+                return (m_securityType <= NetworkManager::Utils::None) ? "network-wireless-60" : "network-wireless-60-locked";
             } else if (m_signal < 80) {
-                return (m_securityType == NetworkManager::Utils::None) ? "network-wireless-80" : "network-wireless-80-locked";
+                return (m_securityType <= NetworkManager::Utils::None) ? "network-wireless-80" : "network-wireless-80-locked";
             } else {
-                return (m_securityType == NetworkManager::Utils::None) ? "network-wireless-100" : "network-wireless-100-locked";
+                return (m_securityType <= NetworkManager::Utils::None) ? "network-wireless-100" : "network-wireless-100-locked";
             }
             break;
         default:
@@ -524,7 +524,7 @@ void NetworkModelItem::updateDetails()
             m_details << i18n("Operator") << gsmNet->operatorName();
         } else {
             ModemManager::ModemCdma::Ptr cdmaNet = modem->interface(ModemManager::ModemDevice::CdmaInterface).objectCast<ModemManager::ModemCdma>();
-            m_details << i18n("Network ID") << QString("%1%").arg(cdmaNet->nid());
+            m_details << i18n("Network ID") << QString("%1").arg(cdmaNet->nid());
         }
         m_details << i18n("Signal Quality") << QString("%1%").arg(modemNetwork->signalQuality().signal);
         m_details << i18n("Access Technology") << UiUtils::convertAccessTechnologyToString(modemNetwork->accessTechnologies());
@@ -603,7 +603,7 @@ void NetworkModelItem::updateDetails()
         NetworkManager::VlanDevice::Ptr vlanDevice = device.objectCast<NetworkManager::VlanDevice>();
         m_details << i18n("Type") << i18n("Vlan");
         if (vlanDevice) {
-            m_details << i18n("Vlan ID") << QString("%1%").arg(vlanDevice->vlanId());
+            m_details << i18n("Vlan ID") << QString("%1").arg(vlanDevice->vlanId());
             m_details << i18n("MAC Address") << vlanDevice->hwAddress();
         }
     } else if (m_type == NetworkManager::ConnectionSettings::Adsl) {
