@@ -24,6 +24,7 @@
 #include "nm-strongswan-service.h"
 #include "ui_strongswanprop.h"
 
+#include <QUrl>
 #include <QString>
 
 class StrongswanSettingWidgetPrivate
@@ -96,17 +97,17 @@ void StrongswanSettingWidget::loadConfig(const NetworkManager::Setting::Ptr &set
         d->ui.leGateway->setText(gateway);
     }
     // Certificate
-    d->ui.leGatewayCertificate->setUrl(KUrl::fromPathOrUrl(dataMap[NM_STRONGSWAN_CERTIFICATE]) );
+    d->ui.leGatewayCertificate->setUrl(QUrl::fromUserInput(dataMap[NM_STRONGSWAN_CERTIFICATE]) );
 
     // Authentication
     const QString method = dataMap[NM_STRONGSWAN_METHOD];
     if (method == QLatin1String(NM_STRONGSWAN_AUTH_KEY)) {
         d->ui.cmbMethod->setCurrentIndex(StrongswanSettingWidgetPrivate::PrivateKey);
-        d->ui.leAuthPrivatekeyCertificate->setUrl(KUrl::fromPathOrUrl(dataMap[NM_STRONGSWAN_USERCERT]));
-        d->ui.leAuthPrivatekeyKey->setUrl(KUrl::fromPathOrUrl(dataMap[NM_STRONGSWAN_USERKEY]));
+        d->ui.leAuthPrivatekeyCertificate->setUrl(QUrl::fromUserInput(dataMap[NM_STRONGSWAN_USERCERT]));
+        d->ui.leAuthPrivatekeyKey->setUrl(QUrl::fromUserInput(dataMap[NM_STRONGSWAN_USERKEY]));
     } else if (method == QLatin1String(NM_STRONGSWAN_AUTH_AGENT)) {
         d->ui.cmbMethod->setCurrentIndex(StrongswanSettingWidgetPrivate::SshAgent);
-        d->ui.leAuthSshCertificate->setUrl(KUrl::fromPathOrUrl(dataMap[NM_STRONGSWAN_USERCERT]));
+        d->ui.leAuthSshCertificate->setUrl(QUrl::fromUserInput(dataMap[NM_STRONGSWAN_USERCERT]));
     } else if (method == QLatin1String(NM_STRONGSWAN_AUTH_SMARTCARD)) {
         d->ui.cmbMethod->setCurrentIndex(StrongswanSettingWidgetPrivate::Smartcard);
     } else if (method == QLatin1String(NM_STRONGSWAN_AUTH_EAP)) {
